@@ -31,7 +31,7 @@ def get_log_msg(contents: dict,
         # content 中, 含有时间，是以时间开头的字符串
         if time_1 is not None and _time_ is not None:
             content = content[len(time_str):].strip()
-    return ' '.join(filter(lambda s: s is not None, [_time_, level, content.encode('unicode_escape').decode('ascii')]))
+    return ' '.join(filter(lambda s: s is not None, [_time_, level, content.replace('\n', '\\n').replace('\t', '\\t')]))
 
 
 def get_from_txt(file_name: str = '_start_time_end_time_str.txt',
